; AquaOS5/theme.jl

(defgroup AquaOS5 "AquaOS5" :group appearance)

(defcustom AquaOS5:active-text "black"
  "Colour of active text."
  :group (appearance AquaOS5)
  :type color)

(defcustom AquaOS5:inactive-text "#576981"
  "Colour of inactive text."
  :group (appearance AquaOS5)
  :type color)  

(defcustom AquaOS5:active-title "title.png"
  "Bar for active title."
  :group (appearance AquaOS5)
  :type file-name)
  
(defcustom AquaOS5:inactive-title "title2.png"
  "Bar for inactive title."
  :group (appearance AquaOS5)
  :type file-name)

(defcustom AquaOS5:ShowIcon t
  "Show window icon on titlebar"
  :user-level novice
  :group (appearance AquaOS5)
  :type boolean)

(defcustom AquaOS5:DefaultIcon ""
  "Default Icon image"
  :user-level expert
  :group (appearance AquaOS5)
  :type file-name)

(let*
  (
   (default-icon (make-image "icon.png"))

   (user-icon ())

   (icon-image (lambda (win)
   	(let
        	((icon (window-icon-image win)))
                (if icon
                	icon
                        (if user-icon
                        	user-icon
                                default-icon
                        )
                )
        )
    ))

    (hide-icon (lambda (win)
   	 (not AquaOS5:ShowIcon)
    ))

    (font-colors (list AquaOS5:inactive-text
                       AquaOS5:active-text))
    
    (close-image (list (make-image "close_button2.png")
                       (make-image "close_button.png")
                       (make-image "close_button_over.png")
                       (make-image "close_button_click.png")))
    (max-image (list (make-image "max_button2.png")
                     (make-image "max_button.png")
                     (make-image "max_button_over.png")
                     (make-image "max_button_click.png")))
    (min-image (list (make-image "min_button2.png")
                     (make-image "min_button.png")
                     (make-image "min_button_over.png")
                     (make-image "min_button_click.png")))
    (menu-image (list (make-image "menu_button2.png")
                      (make-image "menu_button.png")
                      (make-image "menu_button_over.png")
                      (make-image "menu_button_click.png")))
    (title-image (list (make-image AquaOS5:inactive-title)
                       (make-image AquaOS5:active-title)))
    (top-left-image (list (make-image "top_left_button_area2.png")
			  (make-image "top_left_button_area.png")))
    (top-left-shaped-image (make-image "top_left_button_area_shaped.png"))
    (top-right-image (list (make-image "top_right_button_area2.png")
			   (make-image "top_right_button_area.png")))
    (bottom-left-image (list (make-image "bottom_left_corner2.png")
                             (make-image "bottom_left_corner.png")))
    (bottom-image (list (make-image "horizontal_border2.png")
	                (make-image "horizontal_border.png")))
    (bottom-right-image (list (make-image "bottom_right_corner2.png")
                              (make-image "bottom_right_corner.png")))
    (side-image (list (make-image "vertical_border2.png")
                      (make-image "vertical_border.png")))

    (frame `(
        ((background . ,top-left-image)
         (x-justify . left)
         (y-justify . center)
         (top-edge . -20)
         (left-edge . -5)
         (width		. 16)
	 (height	. 20)
         (class . top-left-corner))
        ((background . ,title-image)
         (x-justify . left)
         (y-justify . center)
         (left-edge . 66)
         (top-edge . -20)
	 (width . 22)
         (height . 20)
                        (cursor . left_ptr)
         (class . title))
        ((background . ,icon-image)
         (x-justify . left)
         (y-justify . center)
         (left-edge . 67)
         (top-edge . -20)
         (width . 18)
         (height . 20)
         (hidden . ,hide-icon)
                        (cursor . left_ptr)
         (class . title))
        ((background . ,title-image)
         (foreground . ,font-colors)
         (text . ,window-name)
         (x-justify . left)
         (y-justify . center)
         (left-edge . 88)
         (right-edge . 24)
         (top-edge . -20)
         (height . 20)  
                        (cursor . left_ptr)
         (class . title))
        ((background . ,top-right-image)
         (right-edge . -5)
         (top-edge . -20)
         (width		. 24)
	 (height	. 20)
         (class . top-right-corner))
        ((background . ,side-image)
         (left-edge . -5)
         (top-edge . 0)
         (bottom-edge . 0)
         (class . left-border))
        ((background . ,side-image)
         (right-edge . -5)
         (top-edge . 0)
         (bottom-edge . 0)
         (class . right-border))
        ((background . ,bottom-left-image)
         (left-edge . -5)
         (bottom-edge . -5)
         (class . bottom-left-corner))
        ((background . ,bottom-image)
         (left-edge . 0)
         (right-edge . 0)
         (bottom-edge . -5)
         (class . bottom-border))
        ((background . ,bottom-right-image)
         (right-edge . -5)
         (bottom-edge . -5)
         (class . bottom-right-corner))
        
        ((background . ,close-image)
         (left-edge . 2)
         (top-edge . -20)
                        (cursor . left_ptr)
         (class . close-button))
        ((background . ,max-image)
         (left-edge . 22)
         (top-edge . -20)
                        (cursor . left_ptr)
         (class . maximize-button))
        ((background . ,min-image)
         (left-edge . 44)
         (top-edge . -20)
			(cursor . left_ptr)
         (class . iconify-button))
        ((background . ,menu-image)
         (right-edge . 0)
         (top-edge . -20)
			(cursor . hand2)
         (class . menu-button))
      ))
      
    (shaped-frame `(
        ((background . ,top-left-image)
         (x-justify . left)
         (y-justify . center)
         (top-edge . -20)
         (left-edge . -5)
         (width		. 16)
	 (height	. 20)
         (class . top-left-corner))
        ((background . ,title-image)
         (x-justify . left)
         (y-justify . center)
         (left-edge . 66)
         (top-edge . -20)
         (width . 22)
         (height . 20)
                        (cursor . left_ptr)
         (class . title))
        ((background . ,icon-image)
         (x-justify . left)
         (y-justify . center)
         (left-edge . 67)
         (top-edge . -20)
         (width . 18)
         (height . 20)
         (hidden . ,hide-icon)
                        (cursor . left_ptr)
         (class . title))
        ((background . ,title-image)
         (foreground . ,font-colors)
         (text . ,window-name)
         (x-justify . left)
         (y-justify . center)
         (left-edge . 88)
         (right-edge . 24)
         (top-edge . -20)
         (height . 20)
                        (cursor . left_ptr)
         (class . title))
        ((background . ,top-right-image)
         (right-edge . -5)
         (top-edge . -20)
         (width		. 24)
	 (height	. 20)
         (class . top-right-corner))
        
        ((background . ,close-image)
         (left-edge . 2)
         (top-edge . -20)
                        (cursor . left_ptr)
         (class . close-button))
        ((background . ,max-image)
         (left-edge . 22)
         (top-edge . -20)
                        (cursor . left_ptr)
         (class . maximize-button))
        ((background . ,min-image)
         (left-edge . 44)
         (top-edge . -20)
                        (cursor . left_ptr)
         (class . iconify-button))
        ((background . ,menu-image)
         (right-edge . 0)
         (top-edge . -20)
			(cursor . hand2)
         (class . menu-button))
      ))
      
    (transient-frame `(
        ((background . ,top-left-image)
         (x-justify . left)
         (y-justify . center)
         (top-edge . -20)
         (left-edge . -5)
         (width		. 16)
	 (height	. 20)
         (class . top-left-corner))
        ((background . ,title-image)
         (x-justify . left)
         (y-justify . center)
         (left-edge . 22)
         (top-edge . -20)
         (width . 22)
         (height . 20)
                        (cursor . left_ptr)
         (class . title))
        ((background . ,icon-image)
         (x-justify . left)
         (y-justify . center)
         (left-edge . 23)
         (top-edge . -20)
         (width . 18)
         (height . 20)
         (hidden . ,hide-icon)
                        (cursor . left_ptr)
         (class . title))
        ((background . ,title-image)
         (foreground . ,font-colors)
         (text . ,window-name)
         (x-justify . left)
         (y-justify . center)
         (left-edge . 44)
         (right-edge . 24)
         (top-edge . -20)
         (height . 20)
                        (cursor . left_ptr)
         (class . title))
        ((background . ,top-right-image)
         (right-edge . -5)
         (top-edge . -20)
         (width		. 24)
	 (height	. 20)
         (class . top-right-corner))
        ((background . ,side-image)
         (left-edge . -5)
         (top-edge . 0)
         (bottom-edge . 0)
         (class . left-border))
        ((background . ,side-image)
         (right-edge . -5)
         (top-edge . 0)
         (bottom-edge . 0)
         (class . right-border))
        ((background . ,bottom-left-image)
         (left-edge . -5)
         (bottom-edge . -5)
         (class . bottom-left-corner))
        ((background . ,bottom-image)
         (left-edge . 0)
         (right-edge . 0)
         (bottom-edge . -5)
         (class . bottom-border))
        ((background . ,bottom-right-image)
         (right-edge . -5)
         (bottom-edge . -5)
         (class . bottom-right-corner))
        
        ((background . ,close-image)
         (left-edge . 2)
         (top-edge . -20)
			(cursor . left_ptr)
         (class . close-button))
        ((background . ,menu-image)
         (right-edge . 0)
         (top-edge . -20)
			(cursor . hand2)
         (class . menu-button))
      ))
      
    (shaped-transient-frame `(
        ((background . ,top-left-image)
         (x-justify . left)
         (y-justify . center)
         (top-edge . -20)
         (left-edge . -5)
         (width		. 16)
	 (height	. 20)
         (class . top-left-corner))
        ((background . ,title-image)
         (x-justify . left)
         (y-justify . center)
         (left-edge . 22)
         (top-edge . -20)
         (width . 22)
         (height . 20)
                        (cursor . left_ptr)
         (class . title))
        ((background . ,icon-image)
         (x-justify . left)
         (y-justify . center)
         (left-edge . 23)
         (top-edge . -20)
         (width . 18)
         (height . 20)
         (hidden . ,hide-icon)
                        (cursor . left_ptr)
         (class . title))
        ((background . ,title-image)
         (foreground . ,font-colors)
         (text . ,window-name)
         (x-justify . left)
         (y-justify . center)
         (left-edge . 44)
         (right-edge . 24)
         (top-edge . -20)
         (height . 20)
                        (cursor . left_ptr)
         (class . title))
        ((background . ,top-right-image)
         (right-edge . -5)
         (top-edge . -20)
         (width		. 24)
	 (height	. 20)
         (class . top-right-corner))
        
        ((background . ,close-image)
         (left-edge . 2)
         (top-edge . -20)
                        (cursor . left_ptr)
         (class . close-button))
        ((background . ,menu-image)
         (right-edge . 0)
         (top-edge . -20)
                        (cursor . hand2)
         (class . menu-button))
      ))

   )
      
  (add-frame-style 'AquaOS5
		   (lambda (w type)
		     (case type
			   ((default) frame)
			   ((transient) transient-frame)
			   ((shaped) shaped-frame)
			   ((shaped-transient) shaped-transient-frame))))
)
